@@ -26,7 +26,7 @@
  * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-/* $Header: /home/daffy/u0/vern/flex/RCS/gen.c,v 2.32 93/12/07 11:10:49 vern Exp $ */
+/* $Header: gen.c,v 1.2 94/01/04 14:33:12 vern Exp $ */
 
 #include "flexdef.h"
 
@@ -45,8 +45,10 @@ static int indent_level = 0; /* each level is 8 spaces */
 #define indent_down() (--indent_level)
 #define set_indent(indent_val) indent_level = indent_val
 
-/* *Everything* is done in terms of arrays starting at 1, so provide
- * a null entry for the zero element of all C arrays.
+/* Almost everything is done in terms of arrays starting at 1, so provide
+ * a null entry for the zero element of all C arrays.  (The exception
+ * to this is that the fast table representation generally uses the
+ * 0 elements of its arrays, too.)
  */
 static char C_int_decl[] = "static const int %s[%d] =\n    {   0,\n";
 static char C_short_decl[] = "static const short int %s[%d] =\n    {   0,\n";
@@ -169,16 +171,17 @@ void genctbl()
 	/* So that "make test" won't show arb. differences. */
 	nxt[tblend + 2] = 0;
 
-	/* Make sure every state has a end-of-buffer transition and an
+	/* Make sure every state has an end-of-buffer transition and an
 	 * action #.
 	 */
 	for ( i = 0; i <= lastdfa; ++i )
 		{
-		register int anum = dfaacc[i].dfaacc_state;
+		int anum = dfaacc[i].dfaacc_state;
+		int offset = base[i];
 
-		chk[base[i]] = EOB_POSITION;
-		chk[base[i] - 1] = ACTION_POSITION;
-		nxt[base[i] - 1] = anum;	/* action number */
+		chk[offset] = EOB_POSITION;
+		chk[offset - 1] = ACTION_POSITION;
+		nxt[offset - 1] = anum;	/* action number */
 		}
 
 	for ( i = 0; i <= tblend; ++i )
@@ -594,9 +597,8 @@ int worry_about_NULs;
 		}
 
 	else
-		yy_strcpy( char_map, useecs ?
-					"yy_ec[YY_SC_TO_UI(*yy_cp)]" :
-					"YY_SC_TO_UI(*yy_cp)" );
+		strcpy( char_map, useecs ? "yy_ec[YY_SC_TO_UI(*yy_cp)]" :
+					   "YY_SC_TO_UI(*yy_cp)" );
 
 	if ( worry_about_NULs && nultrans )
 		{
@@ -1053,7 +1055,7 @@ void make_tables()
 		indent_puts(
 		"YY_FATAL_ERROR( \"token too large, exceeds YYLMAX\" ); \\" );
 		indent_down();
-		indent_puts( "yy_strcpy( yytext, yytext_ptr ); \\" );
+		indent_puts( "yy_flex_strcpy( yytext, yytext_ptr ); \\" );
 		}
 
 	set_indent( 0 );
@@ -1254,11 +1256,14 @@ void make_tables()
 		else
 			{
 			printf(
-			"\tif ( yy_current_buffer->is_interactive ) \\\n" );
+			"\tif ( yy_current_buffer->yy_is_interactive ) \\\n" );
+			printf( "\t\t{ \\\n" );
+			printf( "\t\tint c = getc( yyin ); \\\n" );
+			printf( "\t\tresult = c == EOF ? 0 : 1; \\\n" );
+			printf( "\t\tbuf[0] = (char) c; \\\n" );
+			printf( "\t\t} \\\n" );
 			printf(
-"\t\tresult = ((int) (buf[0] = getc( yyin ))) == EOF ? 0 : 1; \\\n" );
-			printf(
-"\telse if ( ((result = fread( (char *) buf, 1, max_size, yyin )) == 0)\\\n" );
+	"\telse if ( ((result = fread( buf, 1, max_size, yyin )) == 0) \\\n" );
 			printf( "\t\t  && ferror( yyin ) ) \\\n" );
 			printf(
 		"\t\tYY_FATAL_ERROR( \"input in flex scanner failed\" );\n" );
